==> monitoring-plugin-1.0.3.tar.gz: monitoring-plugin-1.0.3/monitoring/alarms/urls.py <==
# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2013 Hewlett-Packard Development Company, L.P.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from django.conf.urls import patterns
from django.conf.urls import url

from . import views

urlpatterns = patterns(
    '',
    url(r'^$', views.IndexView.as_view(), name='index'),
    url(r'^status', views.StatusView.as_view(), name='status'),
    url(r'^alarm/(?P<service>[^/]+)/$',
        views.AlarmServiceView.as_view(),
        name='alarm'),
    url(r'^history/(?P<name>[^/]+)/(?P<id>[^/]+)$',
        views.AlarmHistoryView.as_view(),
        name='history'),
    url(r'^meters/(?P<service>[^/]+)$',
        views.AlarmMeterView.as_view(),
        name='meters'),
    url(r'^alarm/(?P<service>[^/]+)/create$',
        views.AlarmCreateView.as_view(),
        name='alarm_create'),
    url(r'^(?P<id>[^/]+)/alarm_detail/$',
        views.AlarmDetailView.as_view(),
        name='alarm_detail'),
    url(r'^alarm/(?P<service>[^/]+)/(?P<id>[^/]+)/alarm_edit/$',
        views.AlarmEditView.as_view(),
        name='alarm_edit'),
)

==> monitoring-plugin-1.0.6.tar.gz: monitoring-plugin-1.0.6/monitoring/alarms/urls.py <==
# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2013 Hewlett-Packard Development Company, L.P.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from django.conf.urls import patterns  # noqa
from django.conf.urls import url  # noqa

from monitoring.alarms import views

urlpatterns = patterns(
    '',
    url(r'^$', views.IndexView.as_view(), name='index'),
    url(r'^status', views.StatusView.as_view(), name='status'),
    url(r'^alarm/(?P<service>[^/]+)/$',
        views.AlarmServiceView.as_view(),
        name='alarm'),
    url(r'^history/(?P<name>[^/]+)/(?P<id>[^/]+)$',
        views.AlarmHistoryView.as_view(),
        name='history'),
    url(r'^meters/(?P<service>[^/]+)$',
        views.AlarmMeterView.as_view(),
        name='meters'),
    url(r'^alarm/(?P<service>[^/]+)/create$',
        views.AlarmCreateView.as_view(),
        name='alarm_create'),
    url(r'^(?P<id>[^/]+)/alarm_detail/$',
        views.AlarmDetailView.as_view(),
        name='alarm_detail'),
    url(r'^alarm/(?P<service>[^/]+)/(?P<id>[^/]+)/alarm_edit/$',
        views.AlarmEditView.as_view(),
        name='alarm_edit'),
)
